summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/tests/commontests.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/macros/tests/commontests.h')
-rw-r--r--kexi/plugins/macros/tests/commontests.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kexi/plugins/macros/tests/commontests.h b/kexi/plugins/macros/tests/commontests.h
index a3199ce2..0480c022 100644
--- a/kexi/plugins/macros/tests/commontests.h
+++ b/kexi/plugins/macros/tests/commontests.h
@@ -31,6 +31,7 @@ namespace KoMacroTest {
class CommonTests : public KUnitTest::SlotTester
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -88,9 +89,9 @@ namespace KoMacroTest {
void testDoubleFunction();
/**
* Test the @a KoMacro::Function functionality with a QString.
*/
- void testQStringFunction();
+ void testTQStringFunction();
/**
* Test the @a KoMacro::Macro functionality.
@@ -88,9 +89,9 @@ namespace KoMacroTest {
void testDoubleFunction();
/**
- * Test the @a KoMacro::Function functionality with a QString.
+ * Test the @a KoMacro::Function functionality with a TQString.
*/